==> windup-web-4.0.0.src.zip: windup-web-4.0.0.Final/ui/src/main/webapp/tests/app/components/executions/executions-data.ts <==
import {WindupExecution} from "../../../../src/app/generated/windup-services";

export const EXECUTIONS_DATA: Partial<WindupExecution>[] = [];

EXECUTIONS_DATA.push({
        "id": 13,
        "version": 1,
        "timeStarted": 1477907641905,
        "timeCompleted": 1477907647229,
        "outputPath": "/home/dklingen/apps/wildfly-10.1.0.Final/standalone/data/windup/reports/Default Group.ANnIuZsNxbfq.report",
        "totalWork": 0,
        "workCompleted": 0,
        "currentTask": null,
        "lastModified": 1477907647318,
        "state": "COMPLETED",
        "analysisContext":
            {
                "id": 11,
                "version": 0,
                "generateStaticReports": true,
                "cloudTargetsIncluded": true,
                "migrationPath": null,
                "advancedOptions": null,
                "rulesPaths": null,
                "includePackages": null,
                "excludePackages": null,
                "applications": [
                    {
                        "id": 3,
                        "version": 0,
                        "registrationType": "UPLOADED",
                        "title": "jee-example-app-1.0.0.ear",
                        "inputPath": null,
                        "fileSize": 0,
                        "exploded": false,
                        "reportIndexPath": null,
                        "created": null,
                        "lastModified": null,
                        "deleted": false,
                        "inputFilename": null
                    }
                ]
            }
        ,
        "filterApplications": null,
        "outputDirectoryName": "Default Group.ANnIuZsNxbfq.report",
        "applicationListRelativePath": "Default Group.ANnIuZsNxbfq.report/index.html",
        "projectId": 1
});

EXECUTIONS_DATA.push({
        "id": 15,
        "version": 1,
        "timeStarted": 1477907945127,
        "timeCompleted": 1477907948439,
        "outputPath": "/home/dklingen/apps/wildfly-10.1.0.Final/standalone/data/windup/reports/Default Group.ANnIuZsNxbfq.report",
        "totalWork": 0,
        "workCompleted": 0,
        "currentTask": null,
        "lastModified": 1477907948484,
        "state": "FAILED",
        "analysisContext":
            {
                "id": 11,
                "version": 0,
                "generateStaticReports": true,
                "cloudTargetsIncluded": true,
                "migrationPath": null,
                "advancedOptions": null,
                "rulesPaths": null,
                "includePackages": null,
                "excludePackages": null,
                "applications": [
                    {
                        "id": 3,
                        "version": 0,
                        "registrationType": "UPLOADED",
                        "title": "jee-example-app-1.0.0.ear",
                        "inputPath": null,
                        "fileSize": 0,
                        "exploded": false,
                        "reportIndexPath": null,
                        "created": null,
                        "lastModified": null,
                        "deleted": false,
                        "inputFilename": null
                    }
                ]
            }
        ,
        "filterApplications": null,
        "outputDirectoryName": "Default Group.ANnIuZsNxbfq.report",
        "applicationListRelativePath": "Default Group.ANnIuZsNxbfq.report/index.html",
        "projectId": 1
});

EXECUTIONS_DATA.push({
        "id": 25,
        "version": 27,
        "timeStarted": 1478000242721,
        "timeCompleted": null,
        "outputPath": "/home/dklingen/apps/wildfly-10.1.0.Final/standalone/data/windup/reports/Default Group.ANnIuZsNxbfq.report",
        "totalWork": 757,
        "workCompleted": 5,
        "currentTask": "PostFinalizePhase - RenderRuleProviderReportRuleProvider - RenderRuleProviderReportRuleProvider_1",
        "lastModified": 1478000316581,
        "state": "STARTED",
        "analysisContext":
            {
                "id": 11,
                "version": 0,
                "generateStaticReports": true,
                "cloudTargetsIncluded": true,
                "migrationPath": null,
                "advancedOptions": null,
                "rulesPaths": null,
                "includePackages": null,
                "excludePackages": null,
                "applications": [
                    {
                        "id": 3,
                        "version": 0,
                        "registrationType": "UPLOADED",
                        "title": "jee-example-app-1.0.0.ear",
                        "inputPath": null,
                        "fileSize": 0,
                        "exploded": false,
                        "reportIndexPath": null,
                        "created": null,
                        "lastModified": null,
                        "deleted": false,
                        "inputFilename": null
                    }
                ]
            }
        ,
        "filterApplications": null,
        "outputDirectoryName": "Default Group.ANnIuZsNxbfq.report",
        "applicationListRelativePath": "Default Group.ANnIuZsNxbfq.report/index.html",
        "projectId": 1
});

EXECUTIONS_DATA.push({
        "id": 30,
        "version": 30,
        "timeStarted": null,
        "timeCompleted": null,
        "outputPath": null,
        "totalWork": 757,
        "workCompleted": 0,
        "currentTask": null,
        "lastModified": 1478000242721,
        "state": "QUEUED",
        "analysisContext":
            {
                "id": 11,
                "version": 0,
                "generateStaticReports": true,
                "cloudTargetsIncluded": true,
                "migrationPath": null,
                "advancedOptions": null,
                "rulesPaths": null,
                "includePackages": null,
                "excludePackages": null,
                "applications": [
                    {
                        "id": 3,
                        "version": 0,
                        "registrationType": "UPLOADED",
                        "title": "jee-example-app-1.0.0.ear",
                        "inputPath": null,
                        "fileSize": 0,
                        "exploded": false,
                        "reportIndexPath": null,
                        "created": null,
                        "lastModified": null,
                        "deleted": false,
                        "inputFilename": null
                    }
                ]
            }
        ,
        "filterApplications": null,
        "outputDirectoryName": "Default Group.ANnIuZsNxbfq.report",
        "applicationListRelativePath": "Default Group.ANnIuZsNxbfq.report/index.html",
        "projectId": 1
});

EXECUTIONS_DATA.push({
        "id": 35,
        "version": 35,
        "timeStarted": 1478000242721,
        "timeCompleted": null,
        "outputPath": null,
        "totalWork": 757,
        "workCompleted": 0,
        "currentTask": null,
        "lastModified": 1478000242721,
        "state": "CANCELLED",
        "analysisContext":
            {
                "id": 11,
                "version": 0,
                "generateStaticReports": true,
                "cloudTargetsIncluded": true,
                "migrationPath": null,
                "advancedOptions": null,
                "rulesPaths": null,
                "includePackages": null,
                "excludePackages": null,
                "applications": [
                    {
                        "id": 3,
                        "version": 0,
                        "registrationType": "UPLOADED",
                        "title": "jee-example-app-1.0.0.ear",
                        "fileSize": 0,
                        "inputPath": null,
                        "exploded": false,
                        "reportIndexPath": null,
                        "created": null,
                        "lastModified": null,
                        "deleted": false,
                        "inputFilename": null
                    }
                ]
            }
        ,
        "filterApplications": null,
        "outputDirectoryName": "Default Group.ANnIuZsNxbfq.report",
        "applicationListRelativePath": "Default Group.ANnIuZsNxbfq.report/index.html",
        "projectId": 1
});

==> windup-web-4.2.0-src.zip: windup-web-4.2.0.Final/ui/src/main/webapp/tests/app/components/executions/executions-data.ts <==
import {WindupExecution} from "../../../../src/app/generated/windup-services";

export const EXECUTIONS_DATA: Partial<WindupExecution>[] = [];

EXECUTIONS_DATA.push({
        "id": 13,
        "version": 1,
        "timeQueued": 1477907641905,
        "timeStarted": 1477907641905,
        "timeCompleted": 1477907647229,
        "outputPath": "/home/dklingen/apps/wildfly-10.1.0.Final/standalone/data/windup/reports/Default Group.ANnIuZsNxbfq.report",
        "totalWork": 0,
        "workCompleted": 0,
        "currentTask": null,
        "lastModified": 1477907647318,
        "state": "COMPLETED",
        "analysisContext":
            {
                "id": 11,
                "version": 0,
                "generateStaticReports": true,
                "cloudTargetsIncluded": true,
                "migrationPath": null,
                "advancedOptions": null,
                "rulesPaths": null,
                "includePackages": null,
                "excludePackages": null,
                "applications": [
                    {
                        "id": 3,
                        "version": 0,
                        "registrationType": "UPLOADED",
                        "title": "jee-example-app-1.0.0.ear",
                        "inputPath": null,
                        "fileSize": 0,
                        "exploded": false,
                        "reportIndexPath": null,
                        "created": null,
                        "lastModified": null,
                        "deleted": false,
                        "inputFilename": null
                    }
                ]
            }
        ,
        "filterApplications": null,
        "outputDirectoryName": "Default Group.ANnIuZsNxbfq.report",
        "applicationListRelativePath": "Default Group.ANnIuZsNxbfq.report/index.html",
        "projectId": 1
});

EXECUTIONS_DATA.push({
        "id": 15,
        "version": 1,
        "timeQueued": 1477907945127,
        "timeStarted": 1477907945127,
        "timeCompleted": 1477907948439,
        "outputPath": "/home/dklingen/apps/wildfly-10.1.0.Final/standalone/data/windup/reports/Default Group.ANnIuZsNxbfq.report",
        "totalWork": 0,
        "workCompleted": 0,
        "currentTask": null,
        "lastModified": 1477907948484,
        "state": "FAILED",
        "analysisContext":
            {
                "id": 11,
                "version": 0,
                "generateStaticReports": true,
                "cloudTargetsIncluded": true,
                "migrationPath": null,
                "advancedOptions": null,
                "rulesPaths": null,
                "includePackages": null,
                "excludePackages": null,
                "applications": [
                    {
                        "id": 3,
                        "version": 0,
                        "registrationType": "UPLOADED",
                        "title": "jee-example-app-1.0.0.ear",
                        "inputPath": null,
                        "fileSize": 0,
                        "exploded": false,
                        "reportIndexPath": null,
                        "created": null,
                        "lastModified": null,
                        "deleted": false,
                        "inputFilename": null
                    }
                ]
            }
        ,
        "filterApplications": null,
        "outputDirectoryName": "Default Group.ANnIuZsNxbfq.report",
        "applicationListRelativePath": "Default Group.ANnIuZsNxbfq.report/index.html",
        "projectId": 1
});

EXECUTIONS_DATA.push({
        "id": 25,
        "version": 27,
        "timeQueued": 1478000242721,
        "timeStarted": 1478000242721,
        "timeCompleted": null,
        "outputPath": "/home/dklingen/apps/wildfly-10.1.0.Final/standalone/data/windup/reports/Default Group.ANnIuZsNxbfq.report",
        "totalWork": 757,
        "workCompleted": 5,
        "currentTask": "PostFinalizePhase - RenderRuleProviderReportRuleProvider - RenderRuleProviderReportRuleProvider_1",
        "lastModified": 1478000316581,
        "state": "STARTED",
        "analysisContext":
            {
                "id": 11,
                "version": 0,
                "generateStaticReports": true,
                "cloudTargetsIncluded": true,
                "migrationPath": null,
                "advancedOptions": null,
                "rulesPaths": null,
                "includePackages": null,
                "excludePackages": null,
                "applications": [
                    {
                        "id": 3,
                        "version": 0,
                        "registrationType": "UPLOADED",
                        "title": "jee-example-app-1.0.0.ear",
                        "inputPath": null,
                        "fileSize": 0,
                        "exploded": false,
                        "reportIndexPath": null,
                        "created": null,
                        "lastModified": null,
                        "deleted": false,
                        "inputFilename": null
                    }
                ]
            }
        ,
        "filterApplications": null,
        "outputDirectoryName": "Default Group.ANnIuZsNxbfq.report",
        "applicationListRelativePath": "Default Group.ANnIuZsNxbfq.report/index.html",
        "projectId": 1
});

EXECUTIONS_DATA.push({
        "id": 30,
        "version": 30,
        "timeQueued": null,
        "timeStarted": null,
        "timeCompleted": null,
        "outputPath": null,
        "totalWork": 757,
        "workCompleted": 0,
        "currentTask": null,
        "lastModified": 1478000242721,
        "state": "QUEUED",
        "analysisContext":
            {
                "id": 11,
                "version": 0,
                "generateStaticReports": true,
                "cloudTargetsIncluded": true,
                "migrationPath": null,
                "advancedOptions": null,
                "rulesPaths": null,
                "includePackages": null,
                "excludePackages": null,
                "applications": [
                    {
                        "id": 3,
                        "version": 0,
                        "registrationType": "UPLOADED",
                        "title": "jee-example-app-1.0.0.ear",
                        "inputPath": null,
                        "fileSize": 0,
                        "exploded": false,
                        "reportIndexPath": null,
                        "created": null,
                        "lastModified": null,
                        "deleted": false,
                        "inputFilename": null
                    }
                ]
            }
        ,
        "filterApplications": null,
        "outputDirectoryName": "Default Group.ANnIuZsNxbfq.report",
        "applicationListRelativePath": "Default Group.ANnIuZsNxbfq.report/index.html",
        "projectId": 1
});

EXECUTIONS_DATA.push({
        "id": 35,
        "version": 35,
        "timeQueued": 1478000242721,
        "timeStarted": 1478000242721,
        "timeCompleted": null,
        "outputPath": null,
        "totalWork": 757,
        "workCompleted": 0,
        "currentTask": null,
        "lastModified": 1478000242721,
        "state": "CANCELLED",
        "analysisContext":
            {
                "id": 11,
                "version": 0,
                "generateStaticReports": true,
                "cloudTargetsIncluded": true,
                "migrationPath": null,
                "advancedOptions": null,
                "rulesPaths": null,
                "includePackages": null,
                "excludePackages": null,
                "applications": [
                    {
                        "id": 3,
                        "version": 0,
                        "registrationType": "UPLOADED",
                        "title": "jee-example-app-1.0.0.ear",
                        "fileSize": 0,
                        "inputPath": null,
                        "exploded": false,
                        "reportIndexPath": null,
                        "created": null,
                        "lastModified": null,
                        "deleted": false,
                        "inputFilename": null
                    }
                ]
            }
        ,
        "filterApplications": null,
        "outputDirectoryName": "Default Group.ANnIuZsNxbfq.report",
        "applicationListRelativePath": "Default Group.ANnIuZsNxbfq.report/index.html",
        "projectId": 1
});
